@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -72,14 +72,14 @@ Plex
 </description>
 
 <installable>
-all
+32,64
 </installable>
 
-<screenshot>https://www.plex.tv/wp-content/uploads/2016/06/image-block-plex-media-server-macbook.jpg</screenshot>
+<screenshot>https://www.plex.tv/wp-content/uploads/2021/05/image-avod-devices-all-may-2021-1440x872.png</screenshot>
 
 <preinstall>
 apt-get install apt-transport-https
-curl https://downloads.plex.tv/plex-keys/PlexSign.key | apt-key add -
+curl https://downloads.plex.tv/plex-keys/PlexSign.key |tee /etc/apt/trusted.gpg.d/plex.asc
 echo "deb https://downloads.plex.tv/repo/deb public main">/etc/apt/sources.list.d/plex-mx.list
 apt-get update
 </preinstall>
