@@ -78,19 +78,19 @@ Skype (64bit only)
 <screenshot>none</screenshot>
 
 <preinstall>
-sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys 1F3045A5DF7587C3
-echo "deb [arch=amd64] https://repo.skype.com/deb stable main">/etc/apt/sources.list.d/pitemp.list
-sleep .1
-apt-get update
+wget https://repo.skype.com/latest/skypeforlinux-64.deb
+dpkg -i skypeforlinux-64.deb
+apt-get -f install
+rm skypeforlinux-64.deb
 </preinstall>
 
 <install_package_names>
-skypeforlinux
+
 </install_package_names>
 
 
 <postinstall>
-rm /etc/apt/sources.list.d/pitemp.list
+
 </postinstall>
 
 
