@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -6,7 +6,7 @@ Browser
 </category>
 
 <name>
-Slimjet
+SlimJet
 </name>
 
 <description>
@@ -75,12 +75,11 @@ Slimjet
 64
 </installable>
 
-<screenshot>https://www.slimjet.com/en/images/newtab.jpg</screenshot>
+<screenshot></screenshot>
 
 <preinstall>
-wget http://www.slimjet.com/release/slimjet_amd64.deb
-dpkg -i slimjet*.deb
-apt-get -f install
+wget https://www.slimjetbrowser.com/release/slimjet_amd64.deb -O /tmp/slimjet_amd64.deb
+apt install /tmp/slimjet_amd64.deb
 </preinstall>
 
 <install_package_names>
@@ -89,7 +88,7 @@ apt-get -f install
 
 
 <postinstall>
-rm slimjet*.deb
+
 </postinstall>
 
 
