@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -79,8 +79,7 @@ Zoom
 
 <preinstall>
 curl -RL https://zoom.us/client/latest/zoom_amd64.deb -o /tmp/zoom.deb
-apt-get -y install /tmp/zoom.deb
-apt-get -f install -y
+apt-get install /tmp/zoom.deb
 </preinstall>
 
 <install_package_names>
